<?php

/* Options Panel */

if ( !function_exists( 'avedontheme_init' ) ) {
define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/inc/' );
require_once dirname( __FILE__ ) . '/inc/options-framework.php';
}

if ( ! isset( $content_width ) )
$content_width = 770;

add_theme_support('post-thumbnails');
add_theme_support( 'post-formats', array( 'aside', 'image', 'gallery', 'link', 'quote', 'status', 'video', 'audio', 'chat' ) );
add_theme_support('automatic-feed-links');
add_theme_support( 'custom-header' );
add_theme_support( 'custom-background' );
add_editor_style();
set_post_thumbnail_size( 300, 300, true );
add_image_size( 'primary-post-thumbnail', 500, 9999 );

if ( function_exists( 'register_nav_menu' ) ) {
register_nav_menu( 'main-menu', 'Main Menu' );
}


/* Fallback Home Link */

function avedon_page_menu_args( $args ) {
$args['show_home'] = true;
return $args;
}
add_filter( 'wp_page_menu_args', 'avedon_page_menu_args' );


/* Include Walker Menu */

include 'helper/walker-menu.php';


/* Posted On */

if ( ! function_exists( 'avedon_posted_on' ) ) :

function avedon_posted_on() {
printf( __( '<span class="sep">Posted on </span><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a><span class="byline"> <span class="sep"> by </span> <span class="author vcard"><a class="url fn n" href="%5$s" title="%6$s" rel="author">%7$s</a></span></span>', 'avedon' ),
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'avedon' ), get_the_author() ) ),
		esc_html( get_the_author() )
	);
}
endif;

if ( ! function_exists( 'avedon_content_nav' ) ):

/* Next / Previous */

function avedon_content_nav( $nav_id ) {
global $wp_query;

?>

<?php if ( is_single() ) : ?>
<ul class="pager row-fluid">
<?php previous_post_link( '<li class="previous span6">%link</li>', '<span class="meta-nav">' . _x( '&larr;', 'Previous post link', 'avedon' ) . '</span> %title' ); ?>
<?php next_post_link( '<li class="next span6">%link</li>', '%title <span class="meta-nav">' . _x( '&rarr;', 'Next post link', 'avedon' ) . '</span>' ); ?>
</ul>
<?php elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : ?>
<ul class="subpager row-fluid">
<?php if ( get_next_posts_link() ) : ?>
<li class="btn next span6"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'avedon' ) ); ?></li>
<?php endif; ?>

<?php if ( get_previous_posts_link() ) : ?>
<li class="btn previous span6"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'avedon' ) ); ?></li>
<?php endif; ?>
</ul>
<?php endif; ?>

<?php
}
endif;


/* Trim Excerpt */

function custom_excerpt_length( $length ) {
	return 30;
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );


/* Meta / Inclusions */

function thousandwords_add_opengraph_doctype( $output ) {
if ( of_get_option('include_ogtag')) { return $output . ' xmlns:fb="http://www.facebook.com/2008/fbml" xmlns:og="http://opengraphprotocol.org/schema/"'; }
}
add_filter('language_attributes', 'thousandwords_add_opengraph_doctype');

function insert_fb_in_head() { global $post; if ( !is_singular()) return;
echo '<meta property="og:title" content="' . get_the_title() . '"/>';
echo '<meta property="og:type" content="article"/>';
echo '<meta property="og:url" content="' . get_permalink() . '"/>';
echo '<meta property="og:site_name" content="' . get_bloginfo('name') . '"/>';
if ( of_get_option('meta_appid')) { echo '<meta property="fb:app_id" content="' . of_get_option('meta_appid') . '"/>'; }
if ( of_get_option('meta_fbadmins')) { echo '<meta property="fb:admins" content="' . of_get_option('meta_fbadmins') . '"/>'; }
if ( !has_post_thumbnail() ) { echo '<meta property="og:image" content="' . of_get_option('meta_defaultimage') . '"/>'; }
else { $thumbnail_src = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'medium' );
echo '<meta property="og:image" content="' . esc_attr( $thumbnail_src[0] ) . '"/>'; }}
add_action( 'wp_head', 'insert_fb_in_head', 1 );

function insert_fb_in_cathead() { global $category ; if ( !is_category()) return;
echo '<meta property="og:title" content="' . get_bloginfo('name') . ' - ' . get_bloginfo( 'description' ) . '"/>';
echo '<meta property="og:type" content="website"/>';
echo '<meta property="og:site_name" content="' . get_bloginfo('name') . '"/>';
if ( of_get_option('meta_defaultimage')) { echo '<meta property="og:image" content="' . of_get_option('meta_defaultimage') . '"/>'; }
if ( of_get_option('meta_appid')) { echo '<meta property="fb:app_id" content="' . of_get_option('meta_appid') . '"/>'; }
if ( of_get_option('meta_fbadmins')) { echo '<meta property="fb:admins" content="' . of_get_option('meta_fbadmins') . '"/>'; }}
add_action( 'wp_head', 'insert_fb_in_cathead', 1 );

function insert_fb_in_homehead() { global $home; if ( !is_home()) return;
echo '<meta property="og:title" content="' . get_bloginfo('name') . ' - ' . get_bloginfo( 'description' ) . '"/>';
echo '<meta property="og:type" content="website"/>';
echo '<meta property="og:site_name" content="' . get_bloginfo('name') . '"/>';
echo '<meta property="og:url" content="' . get_home_url() . '/"/>';
if ( of_get_option('meta_defaultimage')) { echo '<meta property="og:image" content="' . of_get_option('meta_defaultimage') . '"/>'; }
if ( of_get_option('meta_appid')) { echo '<meta property="fb:app_id" content="' . of_get_option('meta_appid') . '"/>'; }
if ( of_get_option('meta_fbadmins')) { echo '<meta property="fb:admins" content="' . of_get_option('meta_fbadmins') . '"/>'; }
if ( of_get_option('meta_description')) { echo '<meta property="og:description" content="' . of_get_option('meta_description') . '"/>'; }}
add_action( 'wp_head', 'insert_fb_in_homehead', 1 );

function insert_verifications() {
if ( of_get_option('google_site_verification')) { echo '<meta name="google-site-verification" content=' . of_get_option('google_site_verification') . ' />'; }
if ( of_get_option('bing_site_verification')) { echo '<meta name="msvalidate.01" content=' . of_get_option('bing_site_verification') . ' />'; }
if ( of_get_option('yahoo_site_verification')) { echo '<meta name="y_key" content=' . of_get_option('yahoo_site_verification') . ' />'; }
if ( of_get_option('google_publisher')) { echo '<link href=' . of_get_option('google_publisher') . ' rel="publisher" />'; }
}

add_action( 'wp_head', 'insert_verifications', 1 );


/* Register Widgets */

function avedon_widgets_init() {

    register_sidebar(array(
    'name' => 'Home Full Feature Content',
    'id'   => 'home-fullfeature-content',
    'description'   => 'Above homepage content - 100% page width. (not recommended if using SuperSize)',
    'before_widget' => '<div id="fullfeature" class="fulltiptop row-fluid %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<span class="hometoptitle">',
    'after_title'   => '</span>'
  ));

    register_sidebar(array(
    'name' => 'Home Feature Content',
    'id'   => 'home-feature-content',
    'description'   => 'Above homepage content - As wide as the content.',
    'before_widget' => '<div id="feature" class="span10 offset1 tiptop %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<span class="hometoptitle">',
    'after_title'   => '</span>'
  ));

    register_sidebar(array(
    'name' => 'Top Content',
    'id'   => 'top-content',
    'description'   => 'Above content, below the menu.',
    'before_widget' => '<div id="%1$s" class="hometoptwo %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<span class="hometoptitle">',
    'after_title'   => '</span>'
  ));

    register_sidebar(array(
    'name' => 'Home Sidebar',
    'id'   => 'home-right',
    'description'   => 'Right sidebar on homepage',
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h3>',
    'after_title'   => '</h3>'
  ));

  register_sidebar( array(
    'name' => 'Page Sidebar',
    'id' => 'sidebar-page',
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget' => "</div>",
    'before_title' => '<h4 class="widget-title">',
    'after_title' => '</h4>',
  ) );

  register_sidebar( array(
    'name' => 'Posts Sidebar',
    'id' => 'sidebar-posts',
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget' => "</div>",
    'before_title' => '<h4 class="widget-title">',
    'after_title' => '</h4>',
  ) );

    register_sidebar(array(
    'name' => 'Call to Action',
    'id'   => 'pitch-content',
    'description'   => 'Under content, over middle - Best used for call to action..',
    'before_widget' => '<div id="pitch" class="row-fluid"><div id="%1$s" class="span10 offset1 widget %2$s">',
    'after_widget'  => '</div></div>',
    'before_title'  => '<h5>',
    'after_title'   => '</h5>'
  ));

    register_sidebar(array(
    'name' => 'Middle Content',
    'id'   => 'bottom-content',
    'description'   => 'Below content, above the footer.',
    'before_widget' => '<div id="mid" class="row-fluid"><div id="%1$s" class="span10 offset1 widget %2$s">',
    'after_widget'  => '</div></div>',
    'before_title'  => '<h4>',
    'after_title'   => '</h4>'
  ));

    register_sidebar(array(
    'name' => 'Bottom Left',
    'id'   => 'bottom-left',
    'description'   => 'Bottom left widget box.',
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h4>',
    'after_title'   => '</h4>'
  ));

    register_sidebar(array(
    'name' => 'Bottom Middle',
    'id'   => 'bottom-middle',
    'description'   => 'Bottom middle widget box.',
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h4>',
    'after_title'   => '</h4>'
  ));

    register_sidebar(array(
    'name' => 'Bottom Right',
    'id'   => 'bottom-right',
    'description'   => 'Bottom right widget box.',
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h4>',
    'after_title'   => '</h4>'
  ));

    register_sidebar(array(
    'name' => 'Footer Content',
    'id'   => 'footer-content',
    'description'   => 'Footer text or acknowledgements',
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget'  => '</div>',
    'before_title'  => '<h4>',
    'after_title'   => '</h4>'
  ));

}
add_action( 'init', 'avedon_widgets_init' );

/* Continue Link */

function avedon_excerpt($more) {
       global $post;
  return '...&nbsp; &nbsp;<a href="'. get_permalink($post->ID) . '" class="btn btn-small">Continue Reading</a>';
}
add_filter('excerpt_more', 'avedon_excerpt');


if ( ! function_exists( 'avedon_posted_on' ) ) :

/* Print Meta */

function avedon_posted_on() {
	printf( __( '<span class="sep">Posted on </span><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a><span class="byline"> <span class="sep"> by </span> <span class="author vcard"><a class="url fn n" href="%5$s" title="%6$s" rel="author">%7$s</a></span></span>', 'avedon' ),
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'avedon' ), get_the_author() ) ),
		esc_html( get_the_author() )
	);
}
endif;


/* Body Classes */

function avedon_body_classes( $classes ) {
	// Adds a class of single-author to blogs with only 1 published author
	if ( ! is_multi_author() ) {
		$classes[] = 'single-author';
	}

	return $classes;
}
add_filter( 'body_class', 'avedon_body_classes' );


/* Multi Category - via http://bootstrapwp.rachelbaker.me */

function avedon_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'all_the_cool_cats' ) ) ) {
		// Create an array of all the categories that are attached to posts
		$all_the_cool_cats = get_categories( array(
			'hide_empty' => 1,
		) );

		// Count the number of categories that are attached to the posts
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'all_the_cool_cats', $all_the_cool_cats );
	}

	if ( '1' != $all_the_cool_cats ) {
		// This blog has more than 1 category so bootstrap_categorized_blog should return true
		return true;
	} else {
		// This blog has only 1 category so bootstrap_categorized_blog should return false
		return false;
	}
}


/* Flush Transients - via http://bootstrapwp.rachelbaker.me */

function avedon_category_transient_flusher() {
  // Like, beat it. Dig?
  delete_transient( 'all_the_cool_cats' );
}
add_action( 'edit_category', 'avedon_category_transient_flusher' );
add_action( 'save_post', 'avedon_category_transient_flusher' );

function avedon_enhanced_image_navigation( $url ) {
	global $post;

	if ( wp_attachment_is_image( $post->ID ) )
		$url = $url . '#main';

	return $url;
}
add_filter( 'attachment_link', 'avedon_enhanced_image_navigation' );

/* Check for Post Thumb */

function avedon_post_thumbnail_check() {
    global $post;
    if (get_the_post_thumbnail()) {
          return true; }
          else { return false; }
}

/* Add Breadcrumbs */

function avedon_breadcrumbs() {

  $delimiter = '<li class="divider">/</li>';
  $home = 'Home'; // text for the 'Home' link
  $before = '<li class="active">'; // tag before the current crumb
  $after = '</li>'; // tag after the current crumb

  if ( !is_home() && !is_front_page() || is_paged() ) {

    echo '<ul class="breadcrumb">';

    global $post;
    $homeLink = home_url();
    echo '<li><a href="' . $homeLink . '">' . $home . '</a></li> ' . $delimiter . ' ';

    if ( is_category() ) {
      global $wp_query;
      $cat_obj = $wp_query->get_queried_object();
      $thisCat = $cat_obj->term_id;
      $thisCat = get_category($thisCat);
      $parentCat = get_category($thisCat->parent);
      if ($thisCat->parent != 0) echo(get_category_parents($parentCat, TRUE, ' ' . $delimiter . ' '));
      echo $before . 'Archive by category "' . single_cat_title('', false) . '"' . $after;

    } elseif ( is_day() ) {
      echo '<li><a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a></li> ' . $delimiter . ' ';
      echo '<li><a href="' . get_month_link(get_the_time('Y'),get_the_time('m')) . '">' . get_the_time('F') . '</a></li> ' . $delimiter . ' ';
      echo $before . get_the_time('d') . $after;

    } elseif ( is_month() ) {
      echo '<li><a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a></li> ' . $delimiter . ' ';
      echo $before . get_the_time('F') . $after;

    } elseif ( is_year() ) {
      echo $before . get_the_time('Y') . $after;

    } elseif ( is_single() && !is_attachment() ) {
      if ( get_post_type() != 'post' ) {
        $post_type = get_post_type_object(get_post_type());
        $slug = $post_type->rewrite;
        echo '<li><a href="' . $homeLink . '/' . $slug['slug'] . '/">' . $post_type->labels->singular_name . '</a></li> ' . $delimiter . ' ';
        echo $before . get_the_title() . $after;
      } else {
        $cat = get_the_category(); $cat = $cat[0];
        echo $before . get_category_parents($cat, TRUE, $after);
		echo $delimiter;
        echo $before . get_the_title() . $after;
      }

    } elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() ) {
      $post_type = get_post_type_object(get_post_type());
      echo $before . $post_type->labels->singular_name . $after;

    } elseif ( is_attachment() ) {
      $parent = get_post($post->post_parent);
      $cat = get_the_category($parent->ID); $cat = $cat[0];
      echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
      echo '<li><a href="' . get_permalink($parent) . '">' . $parent->post_title . '</a></li> ' . $delimiter . ' ';
      echo $before . get_the_title() . $after;

    } elseif ( is_page() && !$post->post_parent ) {
      echo $before . get_the_title() . $after;

    } elseif ( is_page() && $post->post_parent ) {
      $parent_id  = $post->post_parent;
      $breadcrumbs = array();
      while ($parent_id) {
        $page = get_page($parent_id);
        $breadcrumbs[] = '<li><a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a></li>';
        $parent_id  = $page->post_parent;
      }
      $breadcrumbs = array_reverse($breadcrumbs);
      foreach ($breadcrumbs as $crumb) echo $crumb . ' ' . $delimiter . ' ';
      echo $before . get_the_title() . $after;

    } elseif ( is_search() ) {
      echo $before . 'Search results for "' . get_search_query() . '"' . $after;

    } elseif ( is_tag() ) {
      echo $before . 'Posts tagged "' . single_tag_title('', false) . '"' . $after;

    } elseif ( is_author() ) {
       global $author;
      $userdata = get_userdata($author);
      echo $before . 'Articles posted by ' . $userdata->display_name . $after;

    } elseif ( is_404() ) {
      echo $before . 'Error 404' . $after;
    }

    if ( get_query_var('paged') ) {
      if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ' (';
      echo __('Page', 'avedon') . ' ' . get_query_var('paged');
      if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ')';
    }

    echo '</ul>';

  }
}


add_action( 'wp_enqueue_scripts', 'avedon_load_js_files' );

function avedon_load_js_files() {

if (of_get_option('include_fullbootjava') == "1") {
wp_register_script( 'bootstrap', get_template_directory_uri() .'/js/bootstrap.js', array('jquery'), '1.0', true );
wp_enqueue_script( 'bootstrap' );
}
else {
wp_register_script( 'fullbootjava', get_template_directory_uri() .'/js/bootstrap-dropdown.js', array('jquery'), '1.0', true );
wp_enqueue_script( 'fullbootjava' );
}

if (of_get_option('show_supersize') ) {
wp_register_script( 'jqueryeasing', get_template_directory_uri() .'/js/jquery.easing.min.js', array('jquery'), '1.0', true );
wp_register_script( 'supersized', get_template_directory_uri() .'/js/supersized.3.2.7.js', '1.0', true );
wp_register_script( 'supersizedshutter', get_template_directory_uri() .'/js/supersized.shutter.js', '1.0', true );
wp_register_style( 'supercss', get_template_directory_uri() .'/css/supersized.css', '1.0', true );
wp_enqueue_script( 'jqueryeasing' );
wp_enqueue_script( 'supersized' );
wp_enqueue_script( 'supersizedshutter' );
wp_enqueue_style( 'supercss' );
}

if (of_get_option('show_sharingarray') == "1") {
wp_register_script( 'socialcount', get_template_directory_uri() .'/js/socialcount.js', array('jquery'), '1.0', true );
}

if (of_get_option('invert_color') == "color-dark") {
wp_enqueue_style( 'invert_dark', get_template_directory_uri() .'/css/dark.css', '1.0', true );
}

}

/* Custom Scripts */

add_action('avedontheme_custom_scripts', 'avedontheme_custom_scripts');

function avedontheme_custom_scripts() { ?>

<script type="text/javascript">
jQuery(document).ready(function() {

	jQuery('#example_showhidden').click(function() {
  		jQuery('#section-example_text_hidden').fadeToggle(400);
	});

	if (jQuery('#example_showhidden:checked').val() !== undefined) {
		jQuery('#section-example_text_hidden').show();
	}

	jQuery('#social_icons').click(function() {
  		jQuery('#section-twitter_uid').fadeToggle(400);
  		jQuery('#section-googleplus_uid').fadeToggle(400);
  		jQuery('#section-facebook_uid').fadeToggle(400);
  		jQuery('#section-stumble_uid').fadeToggle(400);
  		jQuery('#section-pinterest_uid').fadeToggle(400);
  		jQuery('#section-flickr_uid').fadeToggle(400);
  		jQuery('#section-instagram_uid').fadeToggle(400);
  		jQuery('#section-foursquare_uid').fadeToggle(400);
  		jQuery('#section-youtube_uid').fadeToggle(400);
  		jQuery('#section-vimeo_uid').fadeToggle(400);
  		jQuery('#section-linkedin_uid').fadeToggle(400);
  		jQuery('#section-dribbble_uid').fadeToggle(400);
  		jQuery('#section-forrst_uid').fadeToggle(400);
  		jQuery('#section-wordpress_uid').fadeToggle(400);
  		jQuery('#section-soundcloud_uid').fadeToggle(400);
  		jQuery('#section-lastfm_uid').fadeToggle(400);
  		jQuery('#section-rss_uid').fadeToggle(400);
  		jQuery('#section-sociallink_color').fadeToggle(400);
  		jQuery('#section-sociallinkhover_color').fadeToggle(400);
	});

	if (jQuery('#social_icons:checked').val() !== undefined) {
		jQuery('#section-twitter_uid').show();
		jQuery('#section-googleplus_uid').show();
		jQuery('#section-facebook_uid').show();
		jQuery('#section-stumble_uid').show();
		jQuery('#section-pinterest_uid').show();
		jQuery('#section-flickr_uid').show();
		jQuery('#section-instagram_uid').show();
		jQuery('#section-foursquare_uid').show();
		jQuery('#section-youtube_uid').show();
		jQuery('#section-vimeo_uid').show();
		jQuery('#section-linkedin_uid').show();
		jQuery('#section-dribbble_uid').show();
		jQuery('#section-forrst_uid').show();
		jQuery('#section-wordpress_uid').show();
		jQuery('#section-soundcloud_uid').show();
		jQuery('#section-lastfm_uid').show();
		jQuery('#section-rss_uid').show();
		jQuery('#section-sociallink_color').show();
		jQuery('#section-sociallinkhover_color').show();
	}


	jQuery('#show_supersize').click(function() {
  		jQuery('#section-example_uploadnumber').fadeToggle(400);
  		jQuery('#section-super_effects').fadeToggle(400);
  		jQuery('#section-super_translideint').fadeToggle(400);
  		jQuery('#section-super_transpeed').fadeToggle(400);
  		jQuery('#section-super_mode').fadeToggle(400);
  		jQuery('#section-super_array').fadeToggle(400);
	});

	if (jQuery('#show_supersize:checked').val() !== undefined) {
		jQuery('#section-example_uploadnumber').show();
		jQuery('#section-super_effects').show();
		jQuery('#section-super_translideint').show();
		jQuery('#section-super_transpeed').show();
		jQuery('#section-super_mode').show();
		jQuery('#section-super_array').show();
	}

	jQuery('#radio_images').click(function() {
  		jQuery('#section-radio_image_one').fadeToggle(400);
  		jQuery('#section-radio_image_one_credit').fadeToggle(400);
	});

	if (jQuery('#avedontheme_avedon-radio_images-one:checked').val() !== undefined) {
		jQuery('#section-radio_image_one').show();
		jQuery('#section-radio_image_one_credit').show();
	}

	if (jQuery('#avedontheme_avedon-radio_images-two:checked').val() !== undefined) {
		jQuery('#section-radio_image_one').show();
		jQuery('#section-radio_image_one_credit').show();
		jQuery('#section-radio_image_two').show();
		jQuery('#section-radio_image_two_credit').show();
	}

	if (jQuery('#avedontheme_avedon-radio_images-three:checked').val() !== undefined) {
		jQuery('#section-radio_image_one').show();
		jQuery('#section-radio_image_one_credit').show();
		jQuery('#section-radio_image_two').show();
		jQuery('#section-radio_image_two_credit').show();
		jQuery('#section-radio_image_three').show();
		jQuery('#section-radio_image_three_credit').show();
	}

	if (jQuery('#avedontheme_avedon-radio_images-four:checked').val() !== undefined) {
		jQuery('#section-radio_image_one').show();
		jQuery('#section-radio_image_one_credit').show();
		jQuery('#section-radio_image_two').show();
		jQuery('#section-radio_image_two_credit').show();
		jQuery('#section-radio_image_three').show();
		jQuery('#section-radio_image_three_credit').show();
		jQuery('#section-radio_image_four').show();
		jQuery('#section-radio_image_four_credit').show();
	}

	if (jQuery('#avedontheme_avedon-radio_images-five:checked').val() !== undefined) {
		jQuery('#section-radio_image_one').show();
		jQuery('#section-radio_image_one_credit').show();
		jQuery('#section-radio_image_two').show();
		jQuery('#section-radio_image_two_credit').show();
		jQuery('#section-radio_image_three').show();
		jQuery('#section-radio_image_three_credit').show();
		jQuery('#section-radio_image_four').show();
		jQuery('#section-radio_image_four_credit').show();
		jQuery('#section-radio_image_five').show();
		jQuery('#section-radio_image_five_credit').show();
	}

	if (jQuery('#avedontheme_avedon-radio_images-six:checked').val() !== undefined) {
		jQuery('#section-radio_image_one').show();
		jQuery('#section-radio_image_one_credit').show();
		jQuery('#section-radio_image_two').show();
		jQuery('#section-radio_image_two_credit').show();
		jQuery('#section-radio_image_three').show();
		jQuery('#section-radio_image_three_credit').show();
		jQuery('#section-radio_image_four').show();
		jQuery('#section-radio_image_four_credit').show();
		jQuery('#section-radio_image_five').show();
		jQuery('#section-radio_image_five_credit').show();
		jQuery('#section-radio_image_six').show();
		jQuery('#section-radio_image_six_credit').show();
	}

	jQuery('#show_sharingarray').click(function() {
  		jQuery('#section-sharing_array').fadeToggle(400);
	});

	if (jQuery('#show_sharingarray:checked').val() !== undefined) {
		jQuery('#section-sharing_array').show();
	}

});


</script>



<?php
}